@@ -22,6 +22,7 @@ import shutil
 import random
 import itertools
 import multiprocessing
+from .alignment import AlignmentScoringScheme
 from .assembly_graph import AssemblyGraph
 from .assembly_graph_copy_depth import determine_copy_depth
 from .bridge_long_read_simple import create_simple_long_read_bridges
@@ -33,17 +34,12 @@ from .bridge_loop_unroll import create_loop_unrolling_bridges
 from .misc import int_to_str, float_to_str, quit_with_error, get_percentile, bold, \
     check_input_files, MyHelpFormatter, print_table, get_ascii_art, \
     get_default_thread_count, spades_path_and_version, makeblastdb_path_and_version, \
-    tblastn_path_and_version, bowtie2_build_path_and_version, bowtie2_path_and_version, \
-    samtools_path_and_version, java_path_and_version, pilon_path_and_version, \
-    racon_path_and_version, bcftools_path_and_version, gfa_path, red
+    tblastn_path_and_version, racon_path_and_version, gfa_path, red
 from .spades_func import get_best_spades_graph
 from .blast_func import find_start_gene, CannotFindStart
-from .unicycler_align import add_aligning_arguments, fix_up_arguments, AlignmentScoringScheme, \
-    semi_global_align_long_reads, load_references, load_long_reads, load_sam_alignments, \
-    print_alignment_summary_table
-from .read_ref import get_read_nickname_dict
-from .pilon_func import polish_with_pilon_multiple_rounds, CannotPolish
-from .vcf_func import make_vcf
+from .unicycler_align import fix_up_arguments, semi_global_align_long_reads, load_references, \
+    load_sam_alignments, print_alignment_summary_table
+from .read_ref import get_read_nickname_dict, load_long_reads
 from . import log
 from . import settings
 from .version import __version__
@@ -53,8 +49,7 @@ def main():
     """
     Script execution starts here.
     """
-    # Fix the random seed so the program produces the same output every time it's run.
-    random.seed(0)
+    random.seed(0)  # Fixed seed so the program produces the same output every time it's run.
 
     full_command = ' '.join(('"' + x + '"' if ' ' in x else x) for x in sys.argv)
     args = get_arguments()
@@ -64,17 +59,15 @@ def main():
 
     check_input_files(args)
     print_intro_message(args, full_command, out_dir_message)
-    check_dependencies(args, short_reads_available, long_reads_available)
+    spades_version = check_dependencies(args, short_reads_available, long_reads_available)
 
-    # Files are numbered in chronological order
-    counter = itertools.count(start=1)
+    counter = itertools.count(start=1)  # Files are numbered in chronological order.
     bridges = []
 
-    # If we have short reads, do all the SPAdes stuff.
     if short_reads_available:
-
         # Produce a SPAdes assembly graph with a k-mer that balances contig length and connectivity.
-        best_spades_graph = gfa_path(args.out, next(counter), 'best_spades_graph')
+        spades_graph_prefix = gfa_path(args.out, next(counter), 'spades_graph')[:-4]
+        best_spades_graph = gfa_path(args.out, next(counter), 'depth_filter')
         if os.path.isfile(best_spades_graph):
             log.log('\nSPAdes graph already exists. Will use this graph instead of running '
                     'SPAdes:\n  ' + best_spades_graph)
@@ -84,8 +77,8 @@ def main():
                                           args.depth_filter, args.verbosity,
                                           args.spades_path, args.threads, args.keep,
                                           args.kmer_count, args.min_kmer_frac, args.max_kmer_frac,
-                                          args.kmers, args.no_correct, args.linear_seqs,
-                                          args.spades_tmp_dir, args.largest_component)
+                                          args.kmers, args.linear_seqs, args.largest_component,
+                                          spades_graph_prefix, args.spades_options, spades_version)
         determine_copy_depth(graph)
         if args.keep > 0 and not os.path.isfile(best_spades_graph):
             graph.save_to_gfa(best_spades_graph, save_copy_depth_info=True, newline=True,
@@ -99,16 +92,6 @@ def main():
 
         anchor_segments = get_anchor_segments(graph, args.min_anchor_seg_len)
 
-        # TO DO: SHORT READ ALIGNMENT TO GRAPH
-        # * This would be very useful for a number of reasons:
-        #   * Would allow better calculation of segment depths, which would in turn help with copy
-        #     depth determination.
-        #   * Would allow for better short read bridging.
-
-        # TO DO: SHORT READ BRIDGING?
-        # * I'd like to do my own bridging with short reads, to replace SPAdes contig bridges, which
-        #   can be unreliable.
-
         # Make an initial set of bridges using the SPAdes contig paths. This step is skipped when
         # using conservative bridging mode (in that case we don't trust SPAdes contig paths at all).
         if args.mode != 0:
@@ -117,31 +100,19 @@ def main():
             if not bridges:
                 log.log('none found', 1)
 
-        # Now that we've made short read bridges, we no longer need the paths in the graph.
-        graph.paths = {}
+        graph.paths = {}  # Now that we've made short read bridges, we no longer need the paths.
 
     else:  # short reads not available
         graph = None
         anchor_segments = []
 
-    if short_reads_available and long_reads_available:
-        # TO DO: use long reads to check for misassemblies in short-read assembly graph. If there
-        # is a misassembly (happened in QMP_B2_170), that can totally ruin the rest of the process!
-        # I should do this in the same way I'll use long reads to verify an assembly: minimap
-        # align the reads, then look for locations where the aligned reads have too much overlap.
-
-        # TO DO: tune alignment parameters with last-train
-
-        scoring_scheme = AlignmentScoringScheme(args.scores)
-    else:
-        scoring_scheme = AlignmentScoringScheme(args.scores)
+    scoring_scheme = AlignmentScoringScheme(args.scores)
 
     if long_reads_available:
         read_dict, read_names, long_read_filename = load_long_reads(args.long, output_dir=args.out)
         read_nicknames = get_read_nickname_dict(read_names)
     else:
-        read_dict, read_names, long_read_filename = {}, [], ''
-        read_nicknames = {}
+        read_dict, read_names, long_read_filename, read_nicknames = {}, [], '', {}
 
     if long_reads_available and not args.no_miniasm:
         string_graph = make_miniasm_string_graph(graph, read_dict, long_read_filename,
@@ -150,7 +121,6 @@ def main():
     else:
         string_graph = None
 
-    # If there aren't short reads and the miniasm assembly failed, then there's nothing we can do!
     if not short_reads_available and string_graph is None:
         quit_with_error('miniasm assembly failed')
 
@@ -159,19 +129,20 @@ def main():
             bridges += create_miniasm_bridges(graph, string_graph, anchor_segments,
                                               scoring_scheme, args.verbosity, args.min_bridge_qual)
 
-        bridges += create_simple_long_read_bridges(graph, args.out, args.keep, args.threads,
-                                                   read_dict, long_read_filename, scoring_scheme,
-                                                   anchor_segments)
+        if not args.no_simple_bridges:
+            bridges += create_simple_long_read_bridges(graph, args.out, args.keep, args.threads,
+                                                       read_dict, long_read_filename,
+                                                       scoring_scheme, anchor_segments)
+        if not args.no_long_read_alignment:
+            read_names, min_scaled_score, min_alignment_length = \
+                align_long_reads_to_assembly_graph(graph, anchor_segments, args, full_command,
+                                                   read_dict, read_names, long_read_filename)
 
-        read_names, min_scaled_score, min_alignment_length = \
-            align_long_reads_to_assembly_graph(graph, anchor_segments, args, full_command,
-                                               read_dict, read_names, long_read_filename)
-
-        expected_linear_seqs = args.linear_seqs > 0
-        bridges += create_long_read_bridges(graph, read_dict, read_names, anchor_segments,
-                                            args.verbosity, min_scaled_score, args.threads,
-                                            scoring_scheme, min_alignment_length,
-                                            expected_linear_seqs, args.min_bridge_qual)
+            expected_linear_seqs = args.linear_seqs > 0
+            bridges += create_long_read_bridges(graph, read_dict, read_names, anchor_segments,
+                                                args.verbosity, min_scaled_score, args.threads,
+                                                scoring_scheme, min_alignment_length,
+                                                expected_linear_seqs, args.min_bridge_qual)
 
     if short_reads_available:
         seg_nums_used_in_bridges = graph.apply_bridges(bridges, args.verbosity,
@@ -191,11 +162,10 @@ def main():
         if args.keep > 2:
             graph.save_to_gfa(gfa_path(args.out, next(counter), 'merged'))
 
-        # Perform some final cleaning on the graph.
         log.log_section_header('Bridged assembly graph')
         log.log_explanation('The assembly is now mostly finished and no more structural changes '
                             'will be made. Ideally the assembly graph should now have one contig '
-                            'per replicon and no erroneous contigs (i.e a complete assembly). '
+                            'per replicon and no erroneous contigs (i.e. a complete assembly). '
                             'If there are more contigs, then the assembly is not complete.',
                             verbosity=1)
         graph.final_clean()
@@ -207,25 +177,15 @@ def main():
     else:  # only long reads available
         graph = string_graph
 
-    insert_size_1st, insert_size_99th = None, None
-    if short_reads_available and not args.no_pilon:
-        insert_size_1st, insert_size_99th = \
-            final_polish(graph, args, counter, long_reads_available)
-
     if not args.no_rotate:
         rotate_completed_replicons(graph, args, counter)
 
-    # Save the final state as both a GFA and FASTA file.
     log.log_section_header('Assembly complete')
     final_assembly_fasta = os.path.join(args.out, 'assembly.fasta')
     final_assembly_gfa = os.path.join(args.out, 'assembly.gfa')
     graph.save_to_gfa(final_assembly_gfa)
     graph.save_to_fasta(final_assembly_fasta, min_length=args.min_fasta_length)
 
-    if args.vcf and short_reads_available:
-        final_assembly_vcf = os.path.join(args.out, 'assembly.vcf')
-        make_vcf(final_assembly_vcf, args, final_assembly_fasta, insert_size_1st, insert_size_99th)
-
     log.log('')
 
 
@@ -249,7 +209,6 @@ def get_arguments():
     parser = argparse.ArgumentParser(description=full_description, formatter_class=MyHelpFormatter,
                                      add_help=False)
 
-    # Help options
     help_group = parser.add_argument_group('Help')
     help_group.add_argument('-h', '--help', action='help',
                             help='Show this help message and exit')
@@ -258,20 +217,16 @@ def get_arguments():
     help_group.add_argument('--version', action='version', version='Unicycler v' + __version__,
                             help="Show Unicycler's version number")
 
-    # Short read input options
     input_group = parser.add_argument_group('Input')
     input_group.add_argument('-1', '--short1', required=False,
-                             help='FASTQ file of first short reads in each pair (required)')
+                             help='FASTQ file of first short reads in each pair')
     input_group.add_argument('-2', '--short2', required=False,
-                             help='FASTQ file of second short reads in each pair (required)')
+                             help='FASTQ file of second short reads in each pair')
     input_group.add_argument('-s', '--unpaired', required=False,
-                             help='FASTQ file of unpaired short reads (optional)')
-
-    # Long read input options
+                             help='FASTQ file of unpaired short reads')
     input_group.add_argument('-l', '--long', required=False,
-                             help='FASTQ or FASTA file of long reads (optional)')
+                             help='FASTQ or FASTA file of long reads')
 
-    # Output options
     output_group = parser.add_argument_group('Output')
     output_group.add_argument('-o', '--out', required=True,
                               help='Output directory (required)')
@@ -315,7 +270,6 @@ def get_arguments():
                                   'scaffolding anchors (default: automatic threshold)'
                                   if show_all_args else argparse.SUPPRESS)
 
-    # SPAdes assembly options
     spades_group = parser.add_argument_group('SPAdes assembly',
                                              'These options control the short-read SPAdes '
                                              'assembly at the beginning of the Unicycler pipeline.'
@@ -323,10 +277,6 @@ def get_arguments():
     spades_group.add_argument('--spades_path', type=str, default='spades.py',
                               help='Path to the SPAdes executable'
                                    if show_all_args else argparse.SUPPRESS)
-    spades_group.add_argument('--no_correct', action='store_true',
-                              help='Skip SPAdes error correction step (default: conduct SPAdes '
-                                   'error correction)'
-                                   if show_all_args else argparse.SUPPRESS)
     spades_group.add_argument('--min_kmer_frac', type=float, default=0.2,
                               help='Lowest k-mer size for SPAdes assembly, expressed as a '
                                    'fraction of the read length'
@@ -337,9 +287,9 @@ def get_arguments():
                                    if show_all_args else argparse.SUPPRESS)
     spades_group.add_argument('--kmers', type=str, default=None,
                               help='Exact k-mers to use for SPAdes assembly, comma-separated '
-                                   '(example: 22,33,44, default: automatic)'
+                                   '(example: 21,51,71, default: automatic)'
                                    if show_all_args else argparse.SUPPRESS)
-    spades_group.add_argument('--kmer_count', type=int, default=10,
+    spades_group.add_argument('--kmer_count', type=int, default=8,
                               help='Number of k-mer steps to use in SPAdes assembly'
                                    if show_all_args else argparse.SUPPRESS)
     spades_group.add_argument('--depth_filter', type=float, default=0.25,
@@ -350,13 +300,11 @@ def get_arguments():
                               help='Only keep the largest connected component of the assembly '
                                    'graph (default: keep all connected components)'
                                    if show_all_args else argparse.SUPPRESS)
-    spades_group.add_argument('--spades_tmp_dir', type=str, default=None,
-                              help="Specify SPAdes temporary directory using the SPAdes --tmp-dir "
-                                   "option (default: make a temporary directory in the output "
-                                   "directory)"
+    spades_group.add_argument('--spades_options', type=str, default=None,
+                              help='Additional options to be given to SPAdes (example: '
+                                   '"--phred-offset 33", default: no additional options)'
                                    if show_all_args else argparse.SUPPRESS)
 
-    # Miniasm assembly options
     miniasm_group = parser.add_argument_group('miniasm+Racon assembly',
                                               'These options control the use of miniasm and Racon '
                                               'to produce long-read bridges.'
@@ -369,13 +317,49 @@ def get_arguments():
                                help='Path to the Racon executable'
                                     if show_all_args else argparse.SUPPRESS)
     miniasm_group.add_argument('--existing_long_read_assembly', type=str, default=None,
-                               help='A pre-prepared long read assembly for the sample in GFA '
-                                    'format. If this option is used, Unicycler will skip the '
-                                    'miniasm/Racon steps and instead use the given assembly '
-                                    '(default: perform long read assembly using miniasm/Racon)'
+                               help='A pre-prepared long-read assembly for the sample in GFA '
+                                    'or FASTA format. If this option is used, Unicycler will skip '
+                                    'the miniasm/Racon steps and instead use the given assembly '
+                                    '(default: perform long-read assembly using miniasm/Racon)'
                                     if show_all_args else argparse.SUPPRESS)
 
-    # Rotation options
+    long_group = parser.add_argument_group('Long-read alignment and bridging',
+                                           'These options control the use of long-read alignment '
+                                           'to produce long-read bridges.'
+                                           if show_all_args else argparse.SUPPRESS)
+    long_group.add_argument('--no_simple_bridges', action='store_true',
+                            help='Skip simple long-read bridging (default: use simple '
+                                 'long-read bridging)'
+                                 if show_all_args else argparse.SUPPRESS)
+    long_group.add_argument('--no_long_read_alignment', action='store_true',
+                            help='Skip long-read-alignment-based bridging (default: use long-read '
+                                 'alignments to produce bridges)'
+                                 if show_all_args else argparse.SUPPRESS)
+    long_group.add_argument('--contamination', required=False,
+                            help='FASTA file of known contamination in long reads'
+                            if show_all_args else argparse.SUPPRESS)
+    long_group.add_argument('--scores', type=str, required=False, default='3,-6,-5,-2',
+                            help='Comma-delimited string of alignment scores: match, mismatch, '
+                                 'gap open, gap extend'
+                            if show_all_args else argparse.SUPPRESS)
+    long_group.add_argument('--low_score', type=float, required=False,
+                            help='Score threshold - alignments below this are considered poor '
+                                 '(default: set threshold automatically)'
+                            if show_all_args else argparse.SUPPRESS)
+
+    cleaning_group = parser.add_argument_group('Graph cleaning',
+                                               'These options control the removal of small '
+                                               'leftover sequences after bridging is complete.'
+                                               if show_all_args else argparse.SUPPRESS)
+    cleaning_group.add_argument('--min_component_size', type=int, default=1000,
+                                help='Graph components smaller than this size (bp) will be '
+                                     'removed from the final graph'
+                                     if show_all_args else argparse.SUPPRESS)
+    cleaning_group.add_argument('--min_dead_end_size', type=int, default=1000,
+                                help='Graph dead ends smaller than this size (bp) will be removed '
+                                     'from the final graph'
+                                     if show_all_args else argparse.SUPPRESS)
+
     rotation_group = parser.add_argument_group('Assembly rotation',
                                                'These options control the rotation of completed '
                                                'circular sequence near the end of the Unicycler '
@@ -406,68 +390,6 @@ def get_arguments():
                                 help='Path to the tblastn executable'
                                      if show_all_args else argparse.SUPPRESS)
 
-    # Polishing options
-    polish_group = parser.add_argument_group('Pilon polishing',
-                                             'These options control the final assembly polish '
-                                             'using Pilon at the end of the Unicycler pipeline.'
-                                             if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--no_pilon', action='store_true',
-                              help='Do not use Pilon to polish the final assembly (default: Pilon '
-                                   'is used)'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--bowtie2_path', type=str, default='bowtie2',
-                              help='Path to the bowtie2 executable'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--bowtie2_build_path', type=str, default='bowtie2-build',
-                              help='Path to the bowtie2_build executable'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--samtools_path', type=str, default='samtools',
-                              help='Path to the samtools executable'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--pilon_path', type=str, default='pilon',
-                              help='Path to a Pilon executable or the Pilon Java archive file'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--java_path', type=str, default='java',
-                              help='Path to the java executable'
-                                   if show_all_args else argparse.SUPPRESS)
-    polish_group.add_argument('--min_polish_size', type=int, default=10000,
-                              help='Contigs shorter than this value (bp) will not be polished '
-                                   'using Pilon'
-                                   if show_all_args else argparse.SUPPRESS)
-
-    # VCF options
-    polish_group = parser.add_argument_group('VCF',
-                                             'These options control the production of the VCF of '
-                                             'the final assembly.'
-                                             if show_all_args else argparse.SUPPRESS)
-    output_group.add_argument('--vcf', action='store_true',
-                              help='Produce a VCF by mapping the short reads to the final '
-                                   'assembly (experimental, default: do not produce a vcf file)')
-    polish_group.add_argument('--bcftools_path', type=str, default='bcftools',
-                              help='Path to the bcftools executable'
-                                   if show_all_args else argparse.SUPPRESS)
-
-    # Graph cleaning options
-    cleaning_group = parser.add_argument_group('Graph cleaning',
-                                               'These options control the removal of small '
-                                               'leftover sequences after bridging is complete.'
-                                               if show_all_args else argparse.SUPPRESS)
-    cleaning_group.add_argument('--min_component_size', type=int, default=1000,
-                                help='Graph components smaller than this size (bp) will be '
-                                     'removed from the final graph'
-                                     if show_all_args else argparse.SUPPRESS)
-    cleaning_group.add_argument('--min_dead_end_size', type=int, default=1000,
-                                help='Graph dead ends smaller than this size (bp) will be removed '
-                                     'from the final graph'
-                                     if show_all_args else argparse.SUPPRESS)
-
-    # Add the arguments for the aligner, but suppress the help text.
-    align_group = parser.add_argument_group('Long read alignment',
-                                            'These options control the alignment of long reads to '
-                                            'the assembly graph.'
-                                            if show_all_args else argparse.SUPPRESS)
-    add_aligning_arguments(align_group, show_all_args)
-
     # If no arguments were used, print the entire help (argparse default is to just give an error
     # like '--out is required').
     if len(sys.argv) == 1:
@@ -485,8 +407,8 @@ def get_arguments():
 
     if not (args.long and (args.short1 or args.unpaired)):  # if not a hybrid assembly
         if args.existing_long_read_assembly:
-            quit_with_error('--existing_long_read_assembly can only be used with hybrid '
-                            'assemblies')
+            quit_with_error('--existing_long_read_assembly requires both short and long read '
+                            'inputs')
 
     if args.keep < 0 or args.keep > 3:
         quit_with_error('--keep must be between 0 and 3 (inclusive)')
@@ -540,11 +462,6 @@ def get_arguments():
         args.unpaired = os.path.abspath(args.unpaired)
     if args.long:
         args.long = os.path.abspath(args.long)
-    if args.spades_tmp_dir:
-        args.spades_tmp_dir = os.path.abspath(args.spades_tmp_dir)
-
-    if args.vcf and args.no_pilon:
-        quit_with_error('cannot use --no_pilon with --vcf')
 
     # Create an initial logger which doesn't have an output file.
     log.logger = log.Log(None, args.verbosity)
@@ -641,12 +558,6 @@ def get_anchor_segments(graph, min_anchor_seg_len):
                               if graph.segments[x].get_length() >= min_anchor_seg_len],
                              reverse=True, key=lambda x: x.get_length())
 
-    # TO DO: if long reads are available, I could potentially use them to more reliably determine
-    # whether segments are single-copy or not single-copy. Something like taking all long reads
-    # which align to a segment and seeing if they all cluster together well (based on read-to-read
-    # alignments), implying single-copy, or if they cluster into two or more groups, implying
-    # multi-copy.
-
     log.log('', 2)
     total_anchor_length = sum([x.get_length() for x in anchor_segments])
     log.log(int_to_str(len(anchor_segments)) +
@@ -791,79 +702,33 @@ def check_dependencies(args, short_reads_available, long_reads_available):
     program_table.append(makeblastdb_row)
     program_table.append(tblastn_row)
 
-    # Polishing dependencies
-    if args.no_pilon or not short_reads_available:
-        bowtie2_build_path, bowtie2_build_version, bowtie2_build_status = '', '', 'not used'
-        bowtie2_path, bowtie2_version, bowtie2_status = '', '', 'not used'
-        samtools_path, samtools_version, samtools_status = '', '', 'not used'
-        java_path, java_version, java_status = '', '', 'not used'
-        pilon_path, pilon_version, pilon_status = '', '', 'not used'
-    else:
-        bowtie2_build_path, bowtie2_build_version, bowtie2_build_status = \
-            bowtie2_build_path_and_version(args.bowtie2_build_path)
-        bowtie2_path, bowtie2_version, bowtie2_status = bowtie2_path_and_version(args.bowtie2_path)
-        samtools_path, samtools_version, samtools_status = \
-            samtools_path_and_version(args.samtools_path)
-        java_path, java_version, java_status = java_path_and_version(args.java_path)
-        pilon_path, pilon_version, pilon_status = \
-            pilon_path_and_version(args.pilon_path, args.java_path, args)
-    bowtie2_build_row = ['bowtie2-build', bowtie2_build_version, bowtie2_build_status]
-    bowtie2_row = ['bowtie2', bowtie2_version, bowtie2_status]
-    samtools_row = ['samtools', samtools_version, samtools_status]
-    java_row = ['java', java_version, java_status]
-    pilon_row = ['pilon', pilon_version, pilon_status]
-    if args.verbosity > 1:
-        bowtie2_build_row.append(bowtie2_build_path)
-        bowtie2_row.append(bowtie2_path)
-        samtools_row.append(samtools_path)
-        java_row.append(java_path)
-        pilon_row.append(pilon_path)
-    program_table.append(bowtie2_build_row)
-    program_table.append(bowtie2_row)
-    program_table.append(samtools_row)
-    program_table.append(java_row)
-    program_table.append(pilon_row)
-
-    # VCF dependencies
-    if not args.vcf:
-        bcftools_path, bcftools_version, bcftools_status = '', '', 'not used'
-    else:
-        bcftools_path, bcftools_version, bcftools_status = \
-            bcftools_path_and_version(args.bcftools_path)
-    bcftools_row = ['bcftools', bcftools_version, bcftools_status]
-    if args.verbosity > 1:
-        bcftools_row.append(bcftools_path)
-    program_table.append(bcftools_row)
-
     row_colours = {}
     for i, row in enumerate(program_table):
         if 'not used' in row:
             row_colours[i] = 'dim'
-        elif 'too old' in row or 'not found' in row or 'bad' in row or 'Python problem' in row:
+        elif ('too old' in row or 'too new' in row or 'not found' in row or 'bad' in row or
+              'Python problem' in row):
             row_colours[i] = 'red'
 
     print_table(program_table, alignments='LLLL', row_colour=row_colours, max_col_width=60,
                 sub_colour={'good': 'green'})
 
     quit_if_dependency_problem(spades_status, racon_status, makeblastdb_status, tblastn_status,
-                               bowtie2_build_status, bowtie2_status, samtools_status, java_status,
-                               pilon_status, bcftools_status, args)
+                               args)
+    return spades_version
 
 
 def quit_if_dependency_problem(spades_status, racon_status, makeblastdb_status, tblastn_status,
-                               bowtie2_build_status, bowtie2_status, samtools_status, java_status,
-                               pilon_status, bcftools_status, args):
+                               args):
     if all(x == 'good' or x == 'not used'
-           for x in [spades_status, racon_status, makeblastdb_status, tblastn_status,
-                     bowtie2_build_status, bowtie2_status, samtools_status, java_status,
-                     pilon_status, bcftools_status]):
+           for x in [spades_status, racon_status, makeblastdb_status, tblastn_status]):
         return
 
     log.log('')
     if spades_status == 'not found':
         quit_with_error('could not find SPAdes at ' + args.spades_path)
-    if spades_status == 'too old':
-        quit_with_error('Unicycler requires SPAdes v3.6.2 or higher')
+    if spades_status == 'too old' or spades_status == 'too new':
+        quit_with_error('Unicycler requires SPAdes v3.14.0 or later')
     if spades_status == 'Python problem':
         quit_with_error('SPAdes cannot run due to an incompatible Python version')
     if spades_status == 'bad':
@@ -875,36 +740,11 @@ def quit_if_dependency_problem(spades_status, racon_status, makeblastdb_status,
     if tblastn_status == 'not found':
         quit_with_error('could not find tblastn - either specify its location using '
                         '--tblastn_path or use --no_rotate to remove BLAST dependency')
-    if bowtie2_build_status == 'not found':
-        quit_with_error('could not find bowtie2-build - either specify its location using '
-                        '--bowtie2_build_path or use --no_pilon to remove Bowtie2 dependency')
-    if bowtie2_status == 'not found':
-        quit_with_error('could not find bowtie2 - either specify its location using '
-                        '--bowtie2_path or use --no_pilon to remove Bowtie2 dependency')
-    if samtools_status == 'not found':
-        quit_with_error('could not find samtools - either specify its location using '
-                        '--samtools_path or use --no_pilon to remove Samtools dependency')
-    if java_status == 'not found':
-        quit_with_error('could not find java - either specify its location using --java_path or '
-                        'use --no_pilon to remove Java dependency')
-    if java_status == 'bad':
-        quit_with_error('Java did not run correctly - either specify its location using '
-                        '--java_path or use --no_pilon to remove Java dependency')
-    if pilon_status == 'not found':
-        quit_with_error('could not find pilon or pilon*.jar - either specify its location '
-                        'using --pilon_path or use --no_pilon to remove Pilon dependency')
-    if pilon_status == 'bad':
-        quit_with_error('Pilon was found (' + args.pilon_path + ') but does not work - either '
-                        'fix it, specify a different location using --pilon_path or use '
-                        '--no_pilon to remove Pilon dependency')
     if racon_status == 'not found':
         quit_with_error('could not find racon - either specify its location using --racon_path '
                         'or use --no_miniasm to remove Racon dependency')
     if racon_status == 'bad':
         quit_with_error('Racon was found but does not produce output')
-    if bcftools_status == 'not found':
-        quit_with_error('could not find bcftools - either specify its location using '
-                        '--bcftools_path or exclude --vcf to remove BCFtools dependency')
 
     # Code should never get here!
     quit_with_error('Unspecified error with Unicycler dependencies')
@@ -965,25 +805,6 @@ def rotate_completed_replicons(graph, args, counter):
             shutil.rmtree(blast_dir, ignore_errors=True)
 
 
-def final_polish(graph, args, counter, do_pilon_reassembly):
-    log.log_section_header('Polishing assembly with Pilon')
-    log.log_explanation('Unicycler now conducts multiple rounds of Pilon in an attempt to repair '
-                        'any remaining small-scale errors with the assembly.',
-                        verbosity=1)
-    polish_dir = os.path.join(args.out, 'pilon_polish')
-    insert_size_1st, insert_size_99th = None, None
-    try:
-        insert_size_1st, insert_size_99th = \
-            polish_with_pilon_multiple_rounds(graph, graph, args, polish_dir, do_pilon_reassembly)
-    except CannotPolish as e:
-        log.log('Unable to polish assembly using Pilon: ' + e.message)
-    else:
-        if args.keep > 0:
-            graph.save_to_gfa(gfa_path(args.out, next(counter), 'polished'))
-
-    return insert_size_1st, insert_size_99th
-
-
 def align_long_reads_to_assembly_graph(graph, anchor_segments, args, full_command,
                                        read_dict, read_names, long_read_filename):
     alignment_dir = os.path.join(args.out, 'read_alignment')
@@ -1028,10 +849,6 @@ def align_long_reads_to_assembly_graph(graph, anchor_segments, args, full_comman
         if args.keep < 2:
             shutil.rmtree(alignment_dir, ignore_errors=True)
             log.log('\nDeleting ' + alignment_dir + '/')
-        if args.keep < 3 and os.path.isfile(alignments_sam):
-            os.remove(alignments_sam)
-        if args.keep < 3 and os.path.isfile(graph_fasta):
-            os.remove(graph_fasta)
 
     # Discard any reads that mostly align to known contamination.
     if args.contamination:
