@@ -3,13 +3,10 @@
 Copyright 2017 Ryan Wick (rrwick@gmail.com)
 https://github.com/rrwick/Unicycler
 
-This module makes Unicycler's semi-global long read alignment available as a stand-alone program.
-It is executed when a user runs `unicycler_align` (after installation) or
-`unicycler_align-runner.py`.
-
-Semi-global alignment does not penalise end gaps, but the alignment will continue until one of the
-two sequences ends. This includes cases where the two sequences overlap and cases where one
-sequence is contained within the other:
+This module controls Unicycler's semi-global long read alignment. Semi-global alignment does not
+penalise end gaps, but the alignment will continue until one of the two sequences ends. This
+includes cases where the two sequences overlap and cases where one sequence is contained within the
+other:
 
   TAGAA        GTGCCGGAACA         GGCCACAC     AGTAAGAT
   |||||          |||||||           |||||           |||||
@@ -37,18 +34,14 @@ not, see <http://www.gnu.org/licenses/>.
 
 import sys
 import os
-import argparse
 import time
-import random
-import shutil
 import math
 from multiprocessing.dummy import Pool as ThreadPool
 import threading
-from .misc import int_to_str, float_to_str, check_file_exists, quit_with_error, \
-    weighted_average_list, get_sequence_file_type, MyHelpFormatter, dim, magenta, colour,\
-    get_default_thread_count
-from .read_ref import load_references, load_long_reads
-from .alignment import Alignment, AlignmentScoringScheme
+from .misc import int_to_str, float_to_str, quit_with_error, weighted_average_list, \
+    get_sequence_file_type, dim, magenta, colour
+from .read_ref import load_references
+from .alignment import Alignment
 from . import settings
 from .minimap_alignment import load_minimap_alignments
 from . import log
@@ -73,94 +66,6 @@ SAM_WRITE_LOCK = threading.Lock()
 VERBOSITY = 0
 
 
-def main():
-    """
-    If this script is run on its own, execution starts here.
-    """
-    # Fix the random seed so the program produces the same output every time it's run.
-    random.seed(0)
-
-    full_command = ' '.join(sys.argv)
-    args = get_arguments()
-    check_file_exists(args.ref)
-    check_file_exists(args.reads)
-
-    references = load_references(args.ref)
-    read_dict, read_names, read_filename = load_long_reads(args.reads)
-    scoring_scheme = AlignmentScoringScheme(args.scores)
-
-    semi_global_align_long_reads(references, args.ref, read_dict, read_names, read_filename,
-                                 args.threads, scoring_scheme, [args.low_score], args.keep_bad,
-                                 args.min_len, args.sam, full_command, args.allowed_overlap,
-                                 args.sensitivity, args.contamination, VERBOSITY)
-    sys.exit(0)
-
-
-def get_arguments():
-    """
-    Specifies the command line arguments required by the script.
-    """
-    terminal_width = shutil.get_terminal_size().columns
-    os.environ['COLUMNS'] = str(terminal_width)
-
-    parser = argparse.ArgumentParser(description='Unicycler align - a sensitive semi-global long '
-                                                 'read aligner',
-                                     formatter_class=MyHelpFormatter)
-
-    parser.add_argument('--ref', type=str, required=True,
-                        help='FASTA file containing one or more reference sequences')
-    parser.add_argument('--reads', type=str, required=True,
-                        help='FASTQ or FASTA file of long reads')
-    parser.add_argument('--sam', type=str, required=True,
-                        help='SAM file of resulting alignments')
-
-    add_aligning_arguments(parser, True)
-
-    parser.add_argument('--keep_bad', action='store_true',
-                        help='Include alignments in the results even if they are below the low '
-                             'score threshold (default: low-scoring alignments are discarded)')
-    parser.add_argument('--sensitivity', type=int, default=0,
-                        help='A number from 0 (least sensitive) to 3 (most sensitive)')
-    parser.add_argument('--threads', type=int, required=False, default=get_default_thread_count(),
-                        help='Number of threads used (default: number of CPUs, up to ' +
-                             str(settings.MAX_AUTO_THREAD_COUNT) + ')')
-    parser.add_argument('--verbosity', type=int, required=False, default=1,
-                        help='Level of stdout information (0 to 4)')
-    parser.add_argument('--min_len', type=int, required=False, default=100,
-                        help='Minimum alignment length (bp) - exclude alignments shorter than this '
-                             'length')
-    parser.add_argument('--allowed_overlap', type=int, required=False, default=100,
-                        help='Allow this much overlap between alignments in a single read')
-
-    args = parser.parse_args()
-
-    global VERBOSITY
-    VERBOSITY = args.verbosity
-    log.logger = log.Log(log_filename=None, stdout_verbosity_level=VERBOSITY)
-
-    fix_up_arguments(args)
-
-    return args
-
-
-def add_aligning_arguments(parser, show_help):
-    """
-    Adds some aligning-specific arguments to the parser. These are in a separate function because
-    other tools (e.g. unicycler.py, unicycler_check.py) can use this function too.
-    """
-    parser.add_argument('--contamination', required=False,
-                        help='FASTA file of known contamination in long reads'
-                             if show_help else argparse.SUPPRESS)
-    parser.add_argument('--scores', type=str, required=False, default='3,-6,-5,-2',
-                        help='Comma-delimited string of alignment scores: match, mismatch, '
-                             'gap open, gap extend'
-                             if show_help else argparse.SUPPRESS)
-    parser.add_argument('--low_score', type=float, required=False,
-                        help='Score threshold - alignments below this are considered poor '
-                             '(default: set threshold automatically)'
-                             if show_help else argparse.SUPPRESS)
-
-
 def fix_up_arguments(args):
     # If the user just said 'lambda' for the contamination, then we use the lambda phage FASTA
     # included with Unicycler.
